package oracle.forms.fd;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;


public class ComboMenuBar extends JMenuBar {

  JMenu menu;  
  Dimension preferredSize;
  private ComboMenuPJC      pjc;    
  static int     iWidth = 0, iHeight = 0;

  public ComboMenuBar() {
    
    setBorder(new LineBorder(Color.black));
    //MenuItemListener listener = new MenuItemListener();
    //setListener(menu, listener);    
    //add(menu);
  }
  
  public void setMenu(JMenu m) {
    if(this.menu != null) remove(this.menu);
    this.menu = m;
    setBorder(new LineBorder(Color.black));
    MenuItemListener listener = new MenuItemListener();
    setListener(m, listener);
    add(m);
  }
  
  class MenuItemListener implements ActionListener {
    public void actionPerformed(ActionEvent e) {
      JMenuItem item = (JMenuItem)e.getSource();
      menu.setText(item.getText());
      menu.requestFocus();
      menu.invalidate();
      pjc.setValue(item.getText());
    }    
  }
  
  private void setListener(JMenuItem item,ActionListener listener) {
    if (item instanceof JMenu) {
      JMenu menu = (JMenu)item;
      int n = menu.getItemCount();
      for (int i=0;i<n;i++) {
        setListener(menu.getItem(i), listener);
      }
    } else if (item != null) {
      item.addActionListener(listener);
    }   
  }
  
  
  public String getSelectedItem() {
    return menu.getText();
  }
  
  public void setPreferredSize(Dimension size) {
    preferredSize = size;
  }
  
  public Dimension getPreferredSize() {
    if (preferredSize == null) {
      Dimension sd = super.getPreferredSize();
      Dimension menuD = getItemSize(menu);
      Insets margin = menu.getMargin();
      Dimension retD  = new Dimension(menuD.width,
         margin.top + margin.bottom + menuD.height);
      menu.setPreferredSize(retD);
      preferredSize = retD;
    }
    return preferredSize; 
  }
  
  private Dimension getItemSize(JMenu menu) {
    Dimension d = new Dimension(0,0);
    int n = menu.getItemCount();
    for (int i=0;i<n;i++) {
      Dimension itemD;
      JMenuItem item = menu.getItem(i);
      if (item instanceof JMenu) {
        itemD = getItemSize((JMenu)item);
      } else if (item != null) {
        itemD = item.getPreferredSize();
      } else {
        itemD = new Dimension(0,0);
      }
      d.width  = Math.max(d.width,  itemD.width );
      d.height = Math.max(d.height, itemD.height);
    }
    return d;
  }

  
  public static class ComboMenu extends JMenu {
    ArrowIcon iconRenderer;
    
    public ComboMenu(String label) {
      super(label);
      iconRenderer = new ArrowIcon(SwingConstants.SOUTH, true);
      //setBorder(new EtchedBorder());
      this.setSize(iWidth, iHeight);
      setBorder(null);
      setIcon(new BlankIcon(null, 11));
      setHorizontalTextPosition(JButton.LEFT);
      setFocusPainted(true);
    }
  
    public void paintComponent(Graphics g) {
      super.paintComponent(g);
      Dimension d = this.getPreferredSize();
      int x = Math.max(0, d.width - iconRenderer.getIconWidth() -3);
      int y = Math.max(0, (d.height - iconRenderer.getIconHeight())/2 -2);
      iconRenderer.paintIcon(this,g, x,y);
    }
  }
  
  public static JMenu createMenu(String label) {
    return new ComboMenu(label);
  }
  
   void setPJC (ComboMenuPJC CM) { pjc = CM ;}  
   
   void setComboSize( int w, int h){
       iWidth = w ;
       iHeight = h ;
   }
   
   void setValue( String sValue){
       menu.setText(sValue);
   }
   
   void setMenuBorder(String s){
       if(s.equalsIgnoreCase("line")) setBorder(new LineBorder(Color.black));
       else if(s.equalsIgnoreCase("lowered")) setBorder(new BevelBorder(BevelBorder.LOWERED));
       else if(s.equalsIgnoreCase("raised")) setBorder(new BevelBorder(BevelBorder.RAISED));
       else if(s.equalsIgnoreCase("etched")) setBorder(new EtchedBorder());
       else if(s.equalsIgnoreCase("null")) setBorder(null);
   }

}

